.. _pagetypes:

Bundled Page Type Plugins
=========================

This module ships has a set of plugins bundled by default, as they are useful for a broad range of web sites.
The plugin code also serves as an example and inspiration to create your own modules,
so feel free browse the source code of them.

The available plugins are:

.. toctree::
   :maxdepth: 1

   flatpage
   fluentpage
   redirectnode
   textfile
   others
